魔女宅急便 (豆瓣)
Description: 魔女宅急便电影简介和剧情介绍,魔女宅急便影评、图片、预告片、影讯、论坛、在线购票
Keywords: 魔女宅急便,魔女の宅急便,魔女宅急便影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.199豆瓣电影Top250

# 魔女宅急便 魔女の宅急便 (1989)

导演: 宫崎骏
编剧: 宫崎骏 / 角野荣子
主演: 高山南 / 佐久间玲 / 户田惠子 / 山口胜平 / 信泽三惠子 / 加藤治子 / 关弘子 / 三浦浩一 / 山寺宏一 / 井上喜久子 / 渊崎由里子 / 土井美加 / 土师孝也 / 浅井淑子 / 齐藤昌 / 西村知道 / 小林优子 / 池水通洋 / 辻亲八 / 大塚明夫 / 坂本千夏 / 田口昂 / 键本景子 / 津贺有子 / 龟井芳子 / 丸山裕子
类型: 动画 / 奇幻 / 冒险
制片国家/地区: 日本
语言: 日语
上映日期: 1989-07-29(日本)
片长: 103分钟
又名: 魔女琪琪(台) / 小魔女限时专送 / Kiki's Delivery Service
IMDb: tt0097814
豆瓣评分
引用
8.7
434282人评价
5星
46.3%
4星
43.0%
3星
10.2%
2星
0.4%
1星
0.1%
好于 96% 动画片
好于 97% 奇幻片
想看 看过
评价:
推荐

## 魔女宅急便的剧情简介 · · · · · ·

琪琪今年13岁了，按照魔法界的规矩，魔法少女年满13岁就要出外进行为期一年的修行。所以琪琪带着宠物黑猫吉吉踏上了修行之旅。然而，修行之旅开始得并不顺利，当琪琪来到海边一座大城市时，人们并没有欢迎她的到来，人人都不搭理她。幸亏琪琪有一颗善良的心，当她拾到了一件别人的失物时，热心的琪琪找到了失主。她的善良赢得了面包店老板娘的好感，琪琪就在面包店开始了她用飞行魔法为客人服务的快递业务。琪琪很快适应了新环境，一次，一个热衷于飞机制造的男孩邀请琪琪去参加飞行俱乐部的聚会，途中琪琪因为帮一位老大娘送东西而被雨淋了。从此，琪琪突然发现自己的魔法正在一天天变弱。 ©豆瓣

## 魔女宅急便的演职员 · · · · · · ( 全部 57 )

- 宫崎骏 导演
- 高山南 配 琪琪 / 乌露丝拉 キキ / ウルスラ Kiki / Ursula
- 佐久间玲 配 吉吉 ジジ Jiji
- 户田惠子 配 索娜 おソノ Osono
- 山口胜平 配 蜻蜓 トンボ Tombo
- 信泽三惠子 配 可琪莉 コキリ Kokiri - Kiki's Mother

## 魔女宅急便的图片 · · · · · · ( 添加视频评论 | 图片497 · 添加 )

## 魔女宅急便的获奖情况 · · · · · · ( 全部 )

- 第13届日本电影学院奖
- 话题奖 最具话题影片奖

## 喜欢这部电影的人也喜欢 · · · · · ·

  天空之城

  幽灵公主

  风之谷

  哈尔的移动城堡

  红猪

  猫的报恩

  崖上的波妞

  侧耳倾听

  大闹天宫

  起风了

我要写短评

## 魔女宅急便的短评 · · · · · · ( 全部 68084 条 )

热门 / 最新 / 好友

### 208 有用 有心打扰 看过 2012-04-03 02:02:50

学会一技之能，善加锻炼，让自己承认自己，面对这个庞大的世界，相信自己的能力很重要。

### 1459 有用 水湄物语 看过 2005-11-27 17:25:33

我喜欢她头顶的大红蝴蝶结，还有狠狠白那个小男生的一眼

### 752 有用 漂流瓶bb 看过 2011-04-10 07:53:14

看电影最能触动你的时候，就是电影的宗旨在你最迷茫的时候告诉你现在必须要做什么！KiKI成长了，你呢？KiKi又能飞了，你呢？

### 1288 有用 N 看过 2008-11-18 16:38:20

宫崎骏的电影总让人感觉世界是美好的，阳光明媚的

### 1071 有用 猜猜寻 看过 2012-08-28 20:31:58

宫崎骏的动画总会让人觉得这个世界美好无比。

> 更多短评 68084条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 魔女宅急便的影评 · · · · · · ( 全部 752 条 )

热门 / 最新 / 好友
Rossi 2007-05-27 02:21:37

## 成长的代价——《魔女宅急便》

这篇影评可能有剧透

宅急便，就是速递的意思。这个名字翻译的很失败，国内快递车上都没敢直译“便”字，改成了“宅急送”，因为“急便”实在太容易让人联想到内急。+_+! 看宫崎峻的片子总让人觉得很舒服，这部电影也不例外，延续了一贯的温馨风格，讲述一个成长的故事。 13岁的小魔女琪琪，带着... (展开)
1948 57 119回应 收起
暖言巷陌 2009-02-01 17:44:44

## 飞过城市开出一朵花

家里的香水兰开了，满满的淡雅清香。 微微倦怠的阴天，心里的惆怅与压抑层层叠叠。 13岁的小魔女，骑着扫帚寻找自己的城市。 而19岁的这个寒假，我才恍然知道生而为人的艰难。 也许在这个年龄，不应该再说初涉人世，可许多事情还是超出了自己想象的无奈与悲哀。 要怎么说。 自... (展开)
546 24 114回应 收起
salviati 2008-06-07 02:18:01

## 最后的飞翔公主

很温馨的故事，这个故事是关于成长的。有人说，宫崎骏有女孩情结，这话不假，他的每一部片子几乎都是女孩为主角，从风之谷到前几年的哈尔的移动城堡，每个故事都是有关女孩的。而这一部是同样的，以纯真无邪的女孩为主角，唱出了一首“关于飞行的挽歌”（科幻世界画刊语）。这... (展开)
374 4 37回应 收起
尉迟歌 2011-12-21 14:10:10

## KIKI低落的原因

《小魔女宅急便》的背景一如既往是宫崎骏驾轻就熟的现实与幻想交融的世界，不过作为早期作品，还没有过多沉重的人文关怀主题，主题局限在找寻自我上（人类与环境，内心与自我一直是宫崎骏最喜欢的主题，对了还有少年纯爱，笑），所以电影气氛轻松愉快，适合反复观看。这部作为... (展开)
308 7 29回应 收起
鲨鱼曾给海唱歌 2006-05-02 09:42:39

## 当KIKI飞不起来……谁都有事情无法继续下去的时候

题记： 仅有童话是不够的。当童话变为宫崎骏式的画面在眼前展开的时候，往往会让你注意到别的什么。 《魔女宅急便》的原作是曾获国际安徒生大赏的日本女作家角野荣子，经过宫崎骏的动画功力，再次将观众带入一个美妙的世界... (展开)
175 12 29回应 收起
布丁鼠阿薇 2009-01-15 21:51:05

## 心的修炼

这篇影评可能有剧透

十三岁，到了该离开家的年龄了。背着行囊，带着期望，义无反顾的走向天空，走向那份未知的未来。爸爸抱着kiki说，如果，外面很辛苦，记得回来。当时的我们，都忙不迭的做鬼脸。不会的，我们的未来是那样的美好，不会辛苦~ 出门还是晴朗的夜空，却不久就见到了倾盆大雨。路上我... (展开)
131 36回应 收起
呼小吸 2018-05-27 23:41:22

## 以为十八岁就经历的成长，可能三十五岁才来

这篇影评可能有剧透

周末和闺女一起重温了《魔女宅急便》。 每个魔女十三岁的时候都要离开家，独自去一个没有魔女的城市，独立生活一年，修炼成一个真正的魔女。 魔女琪琪在十三岁的时候已经很向往离开了，她甚至没有等到之前约定的时间，提前飞离了温暖的家。她有忠实的小伙伴黑猫齐齐，她有飞翔... (展开)
93 1 8回应 收起
微風 2015-07-04 23:00:35

## 如果我是一位会飞天的魔女

一直对宫琦骏大师的作品深深喜爱。 今天和孩子回看了魔女宅急便！很温馨！ 孩堤时代曾希望自己是会魔法的少女，对离家闯荡浪迹天涯的生活怀有憧憬，童年时期，沃野中奔跑的女孩飞驰想像力中，我常扮演着逆风飞翔的魔法少女，拥有点石成金、呼风唤雨、瞬间转移...的神奇力量，... (展开)
50 1 0回应 收起
momo 2017-04-21 18:47:13

## 一个可爱的故事，太喜欢男女主了

女主:从小生长在一个魔女家庭。根据古老的传统习俗，她要完成魔女的修行——只要是魔女的孩子，满十三岁就要离开家门，寻找自己的城市开始独立。她有魔力，能听懂宠物猫吉吉说话，她纯洁、天真，喜欢听爸爸的收音机，一个晴朗的月圆之夜，在亲朋好友的送别下，她带着吉吉和爸爸... (展开)
36 1 3回应 收起

> 更多影评 752篇

添加新讨论

## 讨论区 · · · · · ·

努力长大吧 | 来自momo |  | 2022-11-21 20:00:09
为什么宫崎骏电影中大部分的故事背景是欧洲？ | 来自半空中的Eric | 8 回应 | 2022-11-14 16:41:51
KIKI 突然失去能力的理由 | 来自尉迟歌 | 21 回应 | 2022-11-09 19:42:40
很独立吃苦的女孩现在中国还有吗 | 来自haier | 30 回应 | 2022-10-29 21:53:01
琪琪和蜻蜓好了以后 | 来自阿福与阿多 | 4 回应 | 2022-10-25 15:38:23

> 去这部影片的讨论区（全部128条）

## 关于《魔女宅急便》的问题 · · · · · · ( 全部7个 )

- kiki为什么有段时间丧失了魔法？吉吉为什么不会说话了？ 6人回答
- 小魔女在天上飞真的不担心下面的人看到什么吗？ 10人回答

> 全部7个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- 治愈系动画推荐 ([己注销])
- 【爱看动画】 (影志)
- 日本动画推荐 (恶魔的步调)
- 2ch杰出动画排名top200 (千佳的零钱袋)

## 谁在看这部电影 · · · · · ·

- 再见白丝
  刚刚 想看
- 豆友O4WfE_FJiI
  3分钟前 看过
- momo
  4分钟前 看过

897889人看过 / 200917人想看

订阅魔女宅急便的评论:
feed: rss 2.0